# streamlit-bordercontainer

a box which can set style easily

## Installation instructions 

```sh
pip install streamlit-bordercontainer
```

## Usage instructions

```python
import streamlit as st

from st_bordercontainer import st_bordercontainer

value = st_bordercontainer()

st.write(value)
